Wikiquote SimpleBot plugin
==========================

.. image:: https://img.shields.io/pypi/v/simplebot_wikiquote.svg
   :target: https://pypi.org/project/simplebot_wikiquote

.. image:: https://img.shields.io/pypi/pyversions/simplebot_wikiquote.svg
   :target: https://pypi.org/project/simplebot_wikiquote

.. image:: https://pepy.tech/badge/simplebot_wikiquote
   :target: https://pepy.tech/project/simplebot_wikiquote

.. image:: https://img.shields.io/pypi/l/simplebot_wikiquote.svg
   :target: https://pypi.org/project/simplebot_wikiquote

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

A `SimpleBot`_ plugin that allows to see Wikiquote quotes in Delta Chat.

This plugin registers the ``/quote`` command that end-users can use to
get quotes. Example: ``/quote Richard Stallman``.

Install
-------

To install run::

  pip install simplebot-wikiquote


.. _SimpleBot: https://github.com/simplebot-org/simplebot
